[Bf-blender-cvs] [da37b8c2457] master: Minor change to last commit

Campbell Barton noreply at git.blender.org
Thu May 16 10:21:32 CEST 2019


Commit: da37b8c24571a0d6e49d7103a634d47278fde26c
Author: Campbell Barton
Date:   Thu May 16 18:20:45 2019 +1000
Branches: master
https://developer.blender.org/rBda37b8c24571a0d6e49d7103a634d47278fde26c

Minor change to last commit

Don't show a background for the toolbar.

===================================================================

M	source/blender/editors/interface/interface.c

===================================================================

diff --git a/source/blender/editors/interface/interface.c b/source/blender/editors/interface/interface.c
index f334d4a921a..340aa389f3f 100644
--- a/source/blender/editors/interface/interface.c
+++ b/source/blender/editors/interface/interface.c
@@ -1689,8 +1689,14 @@ void UI_block_draw(const bContext *C, uiBlock *block)
     bool show_background = ar->alignment != RGN_ALIGN_FLOAT;
     if (show_background) {
       if (block->panel->type && (block->panel->type->flag & PNL_NO_HEADER)) {
-        /* Without a header there is no background except for region overlap. */
-        show_background = ar->overlap != 0;
+        if (ar->regiontype == RGN_TYPE_TOOLS) {
+          /* We never want a background around active tools. */
+          show_background = false;
+        }
+        else {
+          /* Without a header there is no background except for region overlap. */
+          show_background = ar->overlap != 0;
+        }
       }
     }
     ui_draw_aligned_panel(&style, block, &rect, UI_panel_category_is_visible(ar), show_background);



More information about the Bf-blender-cvs mailing list